module AlexaToolbox
  # Handles creating display directives in responses.
  # https://developer.amazon.com/public/solutions/alexa/alexa-skills-kit/docs/display-interface-reference
  class DisplayDirective
    require 'json'
    require 'alexa_toolbox/display_directive_template'

    attr_accessor :type, :template

    def initialize(template,token)
      @type = "Display.RenderTemplate"
      if ["BodyTemplate1","BodyTemplate2","BodyTemplate3","BodyTemplate6","ListTemplate1","ListTemplate2","ListTemplate3"].include?(template)
        @template = AlexaToolbox::DisplayDirectiveTemplate.new(template,token)
      else
        raise ArgumentError, 'Invalid display template given. Valid options are: "BodyTemplate1","BodyTemplate2","BodyTemplate3","BodyTemplate6","ListTemplate1","ListTemplate2","ListTemplate3"'
      end
    end

    def build_directive(json = true)
      data_hash = {
        "type": @type,
        "template": @template.build
      }
      json ? JSON.parse(data_hash.to_json) : data_hash
    end
  end
end