module AlexaToolbox
  # Handles creating display directives in responses.
  class DisplayDirectiveImage
    require 'json'

    attr_accessor :content_description, :sources

    def initialize(content_description = "", url = nil)
      @content_description = content_description
      @sources = []
      if !url.nil?
        self.add_xsmall_source(url)
      end
    end

    def set_content_description(text)
      @content_description = text
    end

    def add_source(url,size = "X_SMALL",widthPixels = nil,heightPixels = nil)
      source = {
        url: url,
        size: size
      }
      source[:widthPixels] = widthPixels if !widthPixels.nil?
      source[:heightPixels] = heightPixels if !heightPixels.nil?
      @sources.push(source)
    end

    def add_xsmall_source(url)
      @sources.push({
        url: url,
        size: "X_SMALL"
      })
    end

    def add_small_source(url)
      @sources.push({
        url: url,
        size: "SMALL"
      })
    end

    def add_medium_source(url)
      @sources.push({
        url: url,
        size: "MEDIUM"
      })
    end

    def add_large_source(url)
      @sources.push({
        url: url,
        size: "LARGE"
      })
    end

    def add_xlarge_source(url)
      @sources.push({
        url: url,
        size: "X_LARGE"
      })
    end

    def valid?
      @content_description.length > 0 && @sources.count > 0
    end

    def build
      data_hash = {
        contentDescription: @content_description,
        sources: @sources
      }
      data_hash
    end

  end
end