module AlexaToolbox
  # Handles creating display directives in responses.
  class DisplayDirectiveTemplate
    require 'json'
    require 'alexa_toolbox/display_directive_image'
    require 'alexa_toolbox/display_directive_text_content'

    attr_accessor :type, :token, :back_button, :background_image, :title, :text_content, :list_items

    def initialize(type,token,title = nil,back_button = "VISIBLE")
      @type = type
      @token = token
      @back_button = back_button
      @background_image = AlexaToolbox::DisplayDirectiveImage.new
      @title = title
      @text_content = AlexaToolbox::DisplayDirectiveTextContent.new
      @list_items = []
      @image = nil
    end

    def set_token(token)
      @token = token
    end

    def hide_back_button
      @back_button = "HIDDEN"
    end

    def show_back_button
      @back_button = "VISIBLE"
    end

    def add_title(title)
      @title = title
    end

    def add_image_object(image)
      @image = image
    end

    def add_item_to_list(token,image,text_content)
      list_item = {}
      list_item[:token] = token if !token.nil?
      list_item[:image] = image.build if !image.nil?
      list_item[:textContent] = text_content.build if !text_content.nil?
      @list_items.push(list_item)
    end

    def build
      template = {
        :type => @type,
        :token => @token,
        :backButton => @back_button
      }
      template[:backgroundImage] = @background_image.build if @background_image.valid?
      template[:title] = @title if !@title.nil? && @title.length > 0
      template[:textContent] = @text_content.build if @text_content.valid?
      template[:image] = @image.build if !@image.nil? && ["ListTemplate1","ListTemplate2","ListTemplate3","BodyTemplate2","BodyTemplate3","BodyTemplate6"].include?(@type)
      template[:listItems] = @list_items if !@list_items.empty?

      template
    end

  end
end