module AlexaToolbox
  # Handles the session object in requests.
  class Session
    attr_reader :new, :session_id, :attributes, :user, :application_id, :device

    def initialize (session)
      raise ArgumentError, 'Invalid Session' if session.nil? || !session.key?(:new) || !session.key?(:sessionId)
      @new = session[:new]
      @session_id = session[:sessionId]
      @attributes = session[:attributes].nil? ? Hash.new : session[:attributes]
      @user = session[:user]
      @application_id = session[:application][:applicationId]
      @device = session.key?(:device) ? session[:device] : ""
    end

    # Checks whether this is a new session
    def new?
      @new
    end

    # Checks if user is defined
    def user_defined?
      !@user.nil? || !@user[:userId].nil?
    end

    # Returns user's id
    def user_id
      @user[:userId] if @user
    end

    def access_token?
      @user.key?(:accessToken) && !@user[:accessToken].empty?
    end

    # Returns user's access token if provided
    def access_token
      @user[:accessToken] if @user
    end

    def consent_token?
      @user.key?(:permissions) && @user[:permissions].key?(:consentToken) && !@user[:permissions][:consentToken].empty?
    end

    def consent_token
      @user[:permissions][:consentToken] if @user && @user.key?(:permissions) && @user[:permissions].key?(:consentToken)
    end

    def device_id
      @device[:deviceId]
    end

    def supported_interfaces
      @device[:supportedInterfaces]
    end

    # Check to see if attributes are present.
    def has_attributes?
      !@attributes.empty?
    end
  end
end
